@@ -215,6 +215,19 @@ fn string_interpolation_and_paren() {
     assert_eq!(actual.out, "a paren is (");
 }
 
+#[test]
+fn string_interpolation_with_unicode() {
+    //カ = U+30AB : KATAKANA LETTER KA
+    let actual = nu!(
+        cwd: ".",
+        r#"
+            $"カ"
+        "#
+    );
+
+    assert_eq!(actual.out, "カ");
+}
+
 #[test]
 fn bignum_large_integer() {
     let actual = nu!(
